@@ -8,7 +8,7 @@ from .storage import storage
 from .lib.dupedict import DupeDict, JSON
 
 __author__ = 'Anton Hvornum'
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 __description__ = "Our KVM solution, clulstered and self hosted"
 
 # Parse arguments early, so that following imports can
@@ -31,12 +31,18 @@ parser.add_argument("--bios", default=False, action="store_true", help="Disables
 parser.add_argument("--memory", default=8192, nargs="?", help="Defines the amount of memory to allocate to the new machine", type=str)
 parser.add_argument("--harddrives", default=None, nargs="?", help="A comma-separated list of harddrives using the format 'image.qcow2:10G[,image2.qcow2:40G]'", type=str)
 parser.add_argument("--cdroms", default=None, nargs="?", help="A comma-separated list of ISO/cdrom images using the format 'image.iso[,image2.iso]'", type=str)
-parser.add_argument("--network", default=None, nargs="?", help="Defaults to using NAT", type=str)
+parser.add_argument("--no-namespace", default=False, action="store_true", help="This will disable namespace-creation for the machine and by default for network intrastructure")
+parser.add_argument("--graphics", default=False, action="store_true", help="This will turn on default graphics output (gtk) for qemu, the oposit of headless (default)")
+parser.add_argument("--serial", default=False, action="store_true", help="This will turn on serial console graphics (will override --graphics if used together)")
+parser.add_argument("--namespace", default=None, nargs="?", help="Defaults to using the machine name", type=str)
+parser.add_argument("--network", default=None, nargs="?", help="Defaults to using NAT. The syntax is a bit complex, refer to the man pages for information.", type=str)
 parser.add_argument("--uefi-vars", default='/usr/share/ovmf/x64/OVMF_VARS.fd', nargs="?", help="Defines the path to the EFI variables (defaults to using find -iname for the vars)", type=str)
 parser.add_argument("--uefi-code", default='/usr/share/ovmf/x64/OVMF_CODE.fd', nargs="?", help="Defines the path to the EFI code (defaults to using find -iname for the code)", type=str)
 parser.add_argument("--service", default=None, nargs="?", help="Tells ourkvm to create a service script for the newly created machine at the given location. For instance --service ./machine.service", type=str)
 parser.add_argument("--config", default='/etc/qemu.d', nargs="?", help="Tells ourkvm where to store the environment configuration for the newly created machine. Default is /etc/qemu.d/", type=str)
 parser.add_argument("--force", default=False, action="store_true", help="Will overwrite any existing service file or images")
+parser.add_argument("--stop", default=False, action="store_true", help="Will gracefully stop the given machine if it's running (a helper flag for usage with systemd)")
+
 # Store the arguments in a "global" storage variable
 args, unknowns = parser.parse_known_args()
 storage['arguments'] = args
